import geompy
import math
import SALOMEDS


# =====================================================
def PrintMeshInfo(theMesh):
    aMesh = theMesh.GetMesh()
    print "Information about mesh:"
    print "Number of nodes       : ", aMesh.NbNodes()
    print "Number of edges       : ", aMesh.NbEdges()
    print "Number of faces       : ", aMesh.NbFaces()
    print "Number of volumes     : ", aMesh.NbVolumes()
    pass
# =====================================================

Mfineness = 0.15
thickness = 0.02

# define points
p00 = geompy.MakeVertex(0, 0, 0)
p10 = geompy.MakeVertex(1, 0, 0)
p11 = geompy.MakeVertex(1, 1, 0)
p01 = geompy.MakeVertex(0, 1, 0)
pz1 = geompy.MakeVertex(0, 0, 1)

# define vector
vz1 = geompy.MakeVector(p00, pz1)


# define lines between two points
ly0 = geompy.MakeLineTwoPnt(p00, p10)
lx1 = geompy.MakeLineTwoPnt(p10, p11)
ly1 = geompy.MakeLineTwoPnt(p11, p01)
lx0 = geompy.MakeLineTwoPnt(p01, p00)

# define face from 4 wires
Face1 = geompy.MakeFaceWires([ly0, lx1, ly1, lx0], 1)
listSubShapeIDs = geompy.SubShapeAllIDs(Face1, geompy.ShapeType["FACE"])

# define extrusion - base is Face1 in direction of vector vz1 and thickness 0.01
th = thickness
Extrusion1 = geompy.MakePrismVecH(Face1,vz1,th)

listSubShapeIDs = geompy.SubShapeAllIDs(Extrusion1, geompy.ShapeType["EDGE"])
liney1 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(liney1, [11])
Extrusion1 = geompy.GetMainShape(liney1)

linex0 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(linex0, [18])
Extrusion1 = geompy.GetMainShape(linex0)

liney0 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(liney0, [25])
Extrusion1 = geompy.GetMainShape(liney0)

linex1 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(linex1, [29])
Extrusion1 = geompy.GetMainShape(linex1)

# define surfbot
surfbot = geompy.CreateGroup(Extrusion1, geompy.ShapeType["FACE"])
geompy.UnionIDs(surfbot, [31])
Extrusion1 = geompy.GetMainShape(surfbot)

f1 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["FACE"])
geompy.UnionIDs(f1, [20])
Extrusion1 = geompy.GetMainShape(f1)

f2 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["FACE"])
geompy.UnionIDs(f2, [27])
Extrusion1 = geompy.GetMainShape(f2)

f3 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["FACE"])
geompy.UnionIDs(f3, [3])
Extrusion1 = geompy.GetMainShape(f3)

f4 = geompy.CreateGroup(Extrusion1, geompy.ShapeType["FACE"])
geompy.UnionIDs(f4, [13])
Extrusion1 = geompy.GetMainShape(f4)

# add all parts to the study
geompy.addToStudy( p00, "p00" )
geompy.addToStudy( p10, "p10" )
geompy.addToStudy( p11, "p11" )
geompy.addToStudy( p01, "p01" )

geompy.addToStudy( pz1, "pz1" )  # vector
geompy.addToStudy( vz1, "vz1" )  

geompy.addToStudy( ly0, "ly0" )  # lines
geompy.addToStudy( lx1, "lx1" )
geompy.addToStudy( ly1, "ly1" )
geompy.addToStudy( lx0, "lx0" )

geompy.addToStudy( Face1, "Face1" )   # face
geompy.addToStudy( Extrusion1, "Extrusion1" )
geompy.addToStudyInFather( Extrusion1, liney0, "liney0" )
geompy.addToStudyInFather( Extrusion1, linex0, "linex0" )
geompy.addToStudyInFather( Extrusion1, liney1, "liney1" )
geompy.addToStudyInFather( Extrusion1, linex1, "linex1" )
geompy.addToStudyInFather( Extrusion1, surfbot, "surfbot" )
geompy.addToStudyInFather( Extrusion1, f1, "f1" )
geompy.addToStudyInFather( Extrusion1, f2, "f2" )
geompy.addToStudyInFather( Extrusion1, f3, "f3" )
geompy.addToStudyInFather( Extrusion1, f4, "f4" )


#==================================================================
import salome, SMESH
import smesh
import StdMeshers

fineness1 = Mfineness

pattern = smesh.GetPattern()
quad2t = smesh.Mesh(Extrusion1)
Regular_1D = quad2t.Segment()
Automatic_length = Regular_1D.AutomaticLength(fineness1)
Quadratic_quad2t = Regular_1D.QuadraticMesh()
Quadrangle_2D = quad2t.Quadrangle()
Quadrangle_Preference = Quadrangle_2D.QuadranglePreference()
Hexa_3D = quad2t.Hexahedron()

Automatic_length.SetFineness( fineness1 )

isDone = quad2t.Compute()

## set object names  
smesh.SetName(quad2t.GetMesh(), 'quad2t')
smesh.SetName(Regular_1D.GetAlgorithm(), 'Regular_1D')
smesh.SetName(Automatic_length, 'Automatic length')
smesh.SetName(Quadratic_quad2t, 'Quadratic Mesh')
smesh.SetName(Quadrangle_2D.GetAlgorithm(), 'Quadrangle_2D')
smesh.SetName(Quadrangle_Preference, 'Quadrangle Preference')
smesh.SetName(Hexa_3D.GetAlgorithm(), 'Hexa_3D')


Liney0 = quad2t.Group(liney0)
Linex0 = quad2t.Group(linex0)
Liney1 = quad2t.Group(liney1)
Linex1 = quad2t.Group(linex1)
Surfbot = quad2t.Group(surfbot)
F1 = quad2t.Group(f1)
F2 = quad2t.Group(f2)
F3 = quad2t.Group(f3)
F4 = quad2t.Group(f4)

smesh.SetName(quad2t.GetMesh(), 'quad2t')
smesh.SetName(liney0, 'liney0')
smesh.SetName(linex0, 'linex0')
smesh.SetName(liney1, 'liney1')
smesh.SetName(linex1, 'linex1')
smesh.SetName(f1, 'f1')
smesh.SetName(f2, 'f2')
smesh.SetName(f3, 'f3')
smesh.SetName(f4, 'f4')

salome.sg.updateObjBrowser(0)

#quad2t.ExportMED( '/home/kees/solidplate/quad2tq.med',0)
quad2t.ExportMED('<<path>>/quad2tq.med',0)

PrintMeshInfo(quad2t)
#====================

